from google.ads.google_ads.v3 import types as types
from google.ads.google_ads.v3.services import (
    account_budget_proposal_service_client as account_budget_proposal_service_client,
    enums as enums,
)

class AccountBudgetProposalServiceClient(
    account_budget_proposal_service_client.AccountBudgetProposalServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    account_budget_service_client as account_budget_service_client,
)

class AccountBudgetServiceClient(
    account_budget_service_client.AccountBudgetServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_group_ad_asset_view_service_client as ad_group_ad_asset_view_service_client,
)

class AdGroupAdAssetViewServiceClient(
    ad_group_ad_asset_view_service_client.AdGroupAdAssetViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_group_ad_label_service_client as ad_group_ad_label_service_client,
)

class AdGroupAdLabelServiceClient(
    ad_group_ad_label_service_client.AdGroupAdLabelServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_group_ad_service_client as ad_group_ad_service_client,
)

class AdGroupAdServiceClient(ad_group_ad_service_client.AdGroupAdServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_group_audience_view_service_client as ad_group_audience_view_service_client,
)

class AdGroupAudienceViewServiceClient(
    ad_group_audience_view_service_client.AdGroupAudienceViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_group_bid_modifier_service_client as ad_group_bid_modifier_service_client,
)

class AdGroupBidModifierServiceClient(
    ad_group_bid_modifier_service_client.AdGroupBidModifierServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_group_criterion_label_service_client as ad_group_criterion_label_service_client,
)

class AdGroupCriterionLabelServiceClient(
    ad_group_criterion_label_service_client.AdGroupCriterionLabelServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_group_criterion_service_client as ad_group_criterion_service_client,
)

class AdGroupCriterionServiceClient(
    ad_group_criterion_service_client.AdGroupCriterionServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_group_criterion_simulation_service_client as ad_group_criterion_simulation_service_client,
)

class AdGroupCriterionSimulationServiceClient(
    ad_group_criterion_simulation_service_client.AdGroupCriterionSimulationServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_group_extension_setting_service_client as ad_group_extension_setting_service_client,
)

class AdGroupExtensionSettingServiceClient(
    ad_group_extension_setting_service_client.AdGroupExtensionSettingServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_group_feed_service_client as ad_group_feed_service_client,
)

class AdGroupFeedServiceClient(ad_group_feed_service_client.AdGroupFeedServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_group_label_service_client as ad_group_label_service_client,
)

class AdGroupLabelServiceClient(
    ad_group_label_service_client.AdGroupLabelServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_group_service_client as ad_group_service_client,
)

class AdGroupServiceClient(ad_group_service_client.AdGroupServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_group_simulation_service_client as ad_group_simulation_service_client,
)

class AdGroupSimulationServiceClient(
    ad_group_simulation_service_client.AdGroupSimulationServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_parameter_service_client as ad_parameter_service_client,
)

class AdParameterServiceClient(ad_parameter_service_client.AdParameterServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    ad_schedule_view_service_client as ad_schedule_view_service_client,
)

class AdScheduleViewServiceClient(
    ad_schedule_view_service_client.AdScheduleViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import ad_service_client as ad_service_client

class AdServiceClient(ad_service_client.AdServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    age_range_view_service_client as age_range_view_service_client,
)

class AgeRangeViewServiceClient(
    age_range_view_service_client.AgeRangeViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    asset_service_client as asset_service_client,
)

class AssetServiceClient(asset_service_client.AssetServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    bidding_strategy_service_client as bidding_strategy_service_client,
)

class BiddingStrategyServiceClient(
    bidding_strategy_service_client.BiddingStrategyServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    billing_setup_service_client as billing_setup_service_client,
)

class BillingSetupServiceClient(billing_setup_service_client.BillingSetupServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    campaign_audience_view_service_client as campaign_audience_view_service_client,
)

class CampaignAudienceViewServiceClient(
    campaign_audience_view_service_client.CampaignAudienceViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    campaign_bid_modifier_service_client as campaign_bid_modifier_service_client,
)

class CampaignBidModifierServiceClient(
    campaign_bid_modifier_service_client.CampaignBidModifierServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    campaign_budget_service_client as campaign_budget_service_client,
)

class CampaignBudgetServiceClient(
    campaign_budget_service_client.CampaignBudgetServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    campaign_criterion_service_client as campaign_criterion_service_client,
)

class CampaignCriterionServiceClient(
    campaign_criterion_service_client.CampaignCriterionServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    campaign_criterion_simulation_service_client as campaign_criterion_simulation_service_client,
)

class CampaignCriterionSimulationServiceClient(
    campaign_criterion_simulation_service_client.CampaignCriterionSimulationServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    campaign_draft_service_client as campaign_draft_service_client,
)

class CampaignDraftServiceClient(
    campaign_draft_service_client.CampaignDraftServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    campaign_experiment_service_client as campaign_experiment_service_client,
)

class CampaignExperimentServiceClient(
    campaign_experiment_service_client.CampaignExperimentServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    campaign_extension_setting_service_client as campaign_extension_setting_service_client,
)

class CampaignExtensionSettingServiceClient(
    campaign_extension_setting_service_client.CampaignExtensionSettingServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    campaign_feed_service_client as campaign_feed_service_client,
)

class CampaignFeedServiceClient(campaign_feed_service_client.CampaignFeedServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    campaign_label_service_client as campaign_label_service_client,
)

class CampaignLabelServiceClient(
    campaign_label_service_client.CampaignLabelServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    campaign_service_client as campaign_service_client,
)

class CampaignServiceClient(campaign_service_client.CampaignServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    campaign_shared_set_service_client as campaign_shared_set_service_client,
)

class CampaignSharedSetServiceClient(
    campaign_shared_set_service_client.CampaignSharedSetServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    carrier_constant_service_client as carrier_constant_service_client,
)

class CarrierConstantServiceClient(
    carrier_constant_service_client.CarrierConstantServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    change_status_service_client as change_status_service_client,
)

class ChangeStatusServiceClient(change_status_service_client.ChangeStatusServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    click_view_service_client as click_view_service_client,
)

class ClickViewServiceClient(click_view_service_client.ClickViewServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    conversion_action_service_client as conversion_action_service_client,
)

class ConversionActionServiceClient(
    conversion_action_service_client.ConversionActionServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    conversion_adjustment_upload_service_client as conversion_adjustment_upload_service_client,
)

class ConversionAdjustmentUploadServiceClient(
    conversion_adjustment_upload_service_client.ConversionAdjustmentUploadServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    conversion_upload_service_client as conversion_upload_service_client,
)

class ConversionUploadServiceClient(
    conversion_upload_service_client.ConversionUploadServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    currency_constant_service_client as currency_constant_service_client,
)

class CurrencyConstantServiceClient(
    currency_constant_service_client.CurrencyConstantServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    custom_interest_service_client as custom_interest_service_client,
)

class CustomInterestServiceClient(
    custom_interest_service_client.CustomInterestServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    customer_client_link_service_client as customer_client_link_service_client,
)

class CustomerClientLinkServiceClient(
    customer_client_link_service_client.CustomerClientLinkServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    customer_client_service_client as customer_client_service_client,
)

class CustomerClientServiceClient(
    customer_client_service_client.CustomerClientServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    customer_extension_setting_service_client as customer_extension_setting_service_client,
)

class CustomerExtensionSettingServiceClient(
    customer_extension_setting_service_client.CustomerExtensionSettingServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    customer_feed_service_client as customer_feed_service_client,
)

class CustomerFeedServiceClient(customer_feed_service_client.CustomerFeedServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    customer_label_service_client as customer_label_service_client,
)

class CustomerLabelServiceClient(
    customer_label_service_client.CustomerLabelServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    customer_manager_link_service_client as customer_manager_link_service_client,
)

class CustomerManagerLinkServiceClient(
    customer_manager_link_service_client.CustomerManagerLinkServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    customer_negative_criterion_service_client as customer_negative_criterion_service_client,
)

class CustomerNegativeCriterionServiceClient(
    customer_negative_criterion_service_client.CustomerNegativeCriterionServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    customer_service_client as customer_service_client,
)

class CustomerServiceClient(customer_service_client.CustomerServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    detail_placement_view_service_client as detail_placement_view_service_client,
)

class DetailPlacementViewServiceClient(
    detail_placement_view_service_client.DetailPlacementViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    display_keyword_view_service_client as display_keyword_view_service_client,
)

class DisplayKeywordViewServiceClient(
    display_keyword_view_service_client.DisplayKeywordViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    distance_view_service_client as distance_view_service_client,
)

class DistanceViewServiceClient(distance_view_service_client.DistanceViewServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    domain_category_service_client as domain_category_service_client,
)

class DomainCategoryServiceClient(
    domain_category_service_client.DomainCategoryServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    dynamic_search_ads_search_term_view_service_client as dynamic_search_ads_search_term_view_service_client,
)

class DynamicSearchAdsSearchTermViewServiceClient(
    dynamic_search_ads_search_term_view_service_client.DynamicSearchAdsSearchTermViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    expanded_landing_page_view_service_client as expanded_landing_page_view_service_client,
)

class ExpandedLandingPageViewServiceClient(
    expanded_landing_page_view_service_client.ExpandedLandingPageViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    extension_feed_item_service_client as extension_feed_item_service_client,
)

class ExtensionFeedItemServiceClient(
    extension_feed_item_service_client.ExtensionFeedItemServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    feed_item_service_client as feed_item_service_client,
)

class FeedItemServiceClient(feed_item_service_client.FeedItemServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    feed_item_target_service_client as feed_item_target_service_client,
)

class FeedItemTargetServiceClient(
    feed_item_target_service_client.FeedItemTargetServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    feed_mapping_service_client as feed_mapping_service_client,
)

class FeedMappingServiceClient(feed_mapping_service_client.FeedMappingServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    feed_placeholder_view_service_client as feed_placeholder_view_service_client,
)

class FeedPlaceholderViewServiceClient(
    feed_placeholder_view_service_client.FeedPlaceholderViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import feed_service_client as feed_service_client

class FeedServiceClient(feed_service_client.FeedServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    gender_view_service_client as gender_view_service_client,
)

class GenderViewServiceClient(gender_view_service_client.GenderViewServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    geo_target_constant_service_client as geo_target_constant_service_client,
)

class GeoTargetConstantServiceClient(
    geo_target_constant_service_client.GeoTargetConstantServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    geographic_view_service_client as geographic_view_service_client,
)

class GeographicViewServiceClient(
    geographic_view_service_client.GeographicViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    google_ads_field_service_client as google_ads_field_service_client,
)

class GoogleAdsFieldServiceClient(
    google_ads_field_service_client.GoogleAdsFieldServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    google_ads_service_client as google_ads_service_client,
)

class GoogleAdsServiceClient(google_ads_service_client.GoogleAdsServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    group_placement_view_service_client as group_placement_view_service_client,
)

class GroupPlacementViewServiceClient(
    group_placement_view_service_client.GroupPlacementViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    hotel_group_view_service_client as hotel_group_view_service_client,
)

class HotelGroupViewServiceClient(
    hotel_group_view_service_client.HotelGroupViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    hotel_performance_view_service_client as hotel_performance_view_service_client,
)

class HotelPerformanceViewServiceClient(
    hotel_performance_view_service_client.HotelPerformanceViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    invoice_service_client as invoice_service_client,
)

class InvoiceServiceClient(invoice_service_client.InvoiceServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    keyword_plan_ad_group_service_client as keyword_plan_ad_group_service_client,
)

class KeywordPlanAdGroupServiceClient(
    keyword_plan_ad_group_service_client.KeywordPlanAdGroupServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    keyword_plan_campaign_service_client as keyword_plan_campaign_service_client,
)

class KeywordPlanCampaignServiceClient(
    keyword_plan_campaign_service_client.KeywordPlanCampaignServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    keyword_plan_idea_service_client as keyword_plan_idea_service_client,
)

class KeywordPlanIdeaServiceClient(
    keyword_plan_idea_service_client.KeywordPlanIdeaServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    keyword_plan_keyword_service_client as keyword_plan_keyword_service_client,
)

class KeywordPlanKeywordServiceClient(
    keyword_plan_keyword_service_client.KeywordPlanKeywordServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    keyword_plan_negative_keyword_service_client as keyword_plan_negative_keyword_service_client,
)

class KeywordPlanNegativeKeywordServiceClient(
    keyword_plan_negative_keyword_service_client.KeywordPlanNegativeKeywordServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    keyword_plan_service_client as keyword_plan_service_client,
)

class KeywordPlanServiceClient(keyword_plan_service_client.KeywordPlanServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    keyword_view_service_client as keyword_view_service_client,
)

class KeywordViewServiceClient(keyword_view_service_client.KeywordViewServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    label_service_client as label_service_client,
)

class LabelServiceClient(label_service_client.LabelServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    landing_page_view_service_client as landing_page_view_service_client,
)

class LandingPageViewServiceClient(
    landing_page_view_service_client.LandingPageViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    language_constant_service_client as language_constant_service_client,
)

class LanguageConstantServiceClient(
    language_constant_service_client.LanguageConstantServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    location_view_service_client as location_view_service_client,
)

class LocationViewServiceClient(location_view_service_client.LocationViewServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    managed_placement_view_service_client as managed_placement_view_service_client,
)

class ManagedPlacementViewServiceClient(
    managed_placement_view_service_client.ManagedPlacementViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    media_file_service_client as media_file_service_client,
)

class MediaFileServiceClient(media_file_service_client.MediaFileServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    merchant_center_link_service_client as merchant_center_link_service_client,
)

class MerchantCenterLinkServiceClient(
    merchant_center_link_service_client.MerchantCenterLinkServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    mobile_app_category_constant_service_client as mobile_app_category_constant_service_client,
)

class MobileAppCategoryConstantServiceClient(
    mobile_app_category_constant_service_client.MobileAppCategoryConstantServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    mobile_device_constant_service_client as mobile_device_constant_service_client,
)

class MobileDeviceConstantServiceClient(
    mobile_device_constant_service_client.MobileDeviceConstantServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    mutate_job_service_client as mutate_job_service_client,
)

class MutateJobServiceClient(mutate_job_service_client.MutateJobServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    offline_user_data_job_service_client as offline_user_data_job_service_client,
)

class OfflineUserDataJobServiceClient(
    offline_user_data_job_service_client.OfflineUserDataJobServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    operating_system_version_constant_service_client as operating_system_version_constant_service_client,
)

class OperatingSystemVersionConstantServiceClient(
    operating_system_version_constant_service_client.OperatingSystemVersionConstantServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    paid_organic_search_term_view_service_client as paid_organic_search_term_view_service_client,
)

class PaidOrganicSearchTermViewServiceClient(
    paid_organic_search_term_view_service_client.PaidOrganicSearchTermViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    parental_status_view_service_client as parental_status_view_service_client,
)

class ParentalStatusViewServiceClient(
    parental_status_view_service_client.ParentalStatusViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    payments_account_service_client as payments_account_service_client,
)

class PaymentsAccountServiceClient(
    payments_account_service_client.PaymentsAccountServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    product_bidding_category_constant_service_client as product_bidding_category_constant_service_client,
)

class ProductBiddingCategoryConstantServiceClient(
    product_bidding_category_constant_service_client.ProductBiddingCategoryConstantServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    product_group_view_service_client as product_group_view_service_client,
)

class ProductGroupViewServiceClient(
    product_group_view_service_client.ProductGroupViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    reach_plan_service_client as reach_plan_service_client,
)

class ReachPlanServiceClient(reach_plan_service_client.ReachPlanServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    recommendation_service_client as recommendation_service_client,
)

class RecommendationServiceClient(
    recommendation_service_client.RecommendationServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    remarketing_action_service_client as remarketing_action_service_client,
)

class RemarketingActionServiceClient(
    remarketing_action_service_client.RemarketingActionServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    search_term_view_service_client as search_term_view_service_client,
)

class SearchTermViewServiceClient(
    search_term_view_service_client.SearchTermViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    shared_criterion_service_client as shared_criterion_service_client,
)

class SharedCriterionServiceClient(
    shared_criterion_service_client.SharedCriterionServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    shared_set_service_client as shared_set_service_client,
)

class SharedSetServiceClient(shared_set_service_client.SharedSetServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    shopping_performance_view_service_client as shopping_performance_view_service_client,
)

class ShoppingPerformanceViewServiceClient(
    shopping_performance_view_service_client.ShoppingPerformanceViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    topic_constant_service_client as topic_constant_service_client,
)

class TopicConstantServiceClient(
    topic_constant_service_client.TopicConstantServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    topic_view_service_client as topic_view_service_client,
)

class TopicViewServiceClient(topic_view_service_client.TopicViewServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    user_data_service_client as user_data_service_client,
)

class UserDataServiceClient(user_data_service_client.UserDataServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    user_interest_service_client as user_interest_service_client,
)

class UserInterestServiceClient(user_interest_service_client.UserInterestServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    user_list_service_client as user_list_service_client,
)

class UserListServiceClient(user_list_service_client.UserListServiceClient):
    enums = enums

from google.ads.google_ads.v3.services import (
    user_location_view_service_client as user_location_view_service_client,
)

class UserLocationViewServiceClient(
    user_location_view_service_client.UserLocationViewServiceClient
):
    enums = enums

from google.ads.google_ads.v3.services import (
    video_service_client as video_service_client,
)

class VideoServiceClient(video_service_client.VideoServiceClient):
    enums = enums

from google.ads.google_ads.v3.services.transports import (
    account_budget_proposal_service_grpc_transport as account_budget_proposal_service_grpc_transport,
)

class AccountBudgetProposalServiceGrpcTransport(
    account_budget_proposal_service_grpc_transport.AccountBudgetProposalServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    account_budget_service_grpc_transport as account_budget_service_grpc_transport,
)

class AccountBudgetServiceGrpcTransport(
    account_budget_service_grpc_transport.AccountBudgetServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_group_ad_asset_view_service_grpc_transport as ad_group_ad_asset_view_service_grpc_transport,
)

class AdGroupAdAssetViewServiceGrpcTransport(
    ad_group_ad_asset_view_service_grpc_transport.AdGroupAdAssetViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_group_ad_label_service_grpc_transport as ad_group_ad_label_service_grpc_transport,
)

class AdGroupAdLabelServiceGrpcTransport(
    ad_group_ad_label_service_grpc_transport.AdGroupAdLabelServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_group_ad_service_grpc_transport as ad_group_ad_service_grpc_transport,
)

class AdGroupAdServiceGrpcTransport(
    ad_group_ad_service_grpc_transport.AdGroupAdServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_group_audience_view_service_grpc_transport as ad_group_audience_view_service_grpc_transport,
)

class AdGroupAudienceViewServiceGrpcTransport(
    ad_group_audience_view_service_grpc_transport.AdGroupAudienceViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_group_bid_modifier_service_grpc_transport as ad_group_bid_modifier_service_grpc_transport,
)

class AdGroupBidModifierServiceGrpcTransport(
    ad_group_bid_modifier_service_grpc_transport.AdGroupBidModifierServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_group_criterion_label_service_grpc_transport as ad_group_criterion_label_service_grpc_transport,
)

class AdGroupCriterionLabelServiceGrpcTransport(
    ad_group_criterion_label_service_grpc_transport.AdGroupCriterionLabelServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_group_criterion_service_grpc_transport as ad_group_criterion_service_grpc_transport,
)

class AdGroupCriterionServiceGrpcTransport(
    ad_group_criterion_service_grpc_transport.AdGroupCriterionServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_group_criterion_simulation_service_grpc_transport as ad_group_criterion_simulation_service_grpc_transport,
)

class AdGroupCriterionSimulationServiceGrpcTransport(
    ad_group_criterion_simulation_service_grpc_transport.AdGroupCriterionSimulationServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_group_extension_setting_service_grpc_transport as ad_group_extension_setting_service_grpc_transport,
)

class AdGroupExtensionSettingServiceGrpcTransport(
    ad_group_extension_setting_service_grpc_transport.AdGroupExtensionSettingServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_group_feed_service_grpc_transport as ad_group_feed_service_grpc_transport,
)

class AdGroupFeedServiceGrpcTransport(
    ad_group_feed_service_grpc_transport.AdGroupFeedServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_group_label_service_grpc_transport as ad_group_label_service_grpc_transport,
)

class AdGroupLabelServiceGrpcTransport(
    ad_group_label_service_grpc_transport.AdGroupLabelServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_group_service_grpc_transport as ad_group_service_grpc_transport,
)

class AdGroupServiceGrpcTransport(
    ad_group_service_grpc_transport.AdGroupServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_group_simulation_service_grpc_transport as ad_group_simulation_service_grpc_transport,
)

class AdGroupSimulationServiceGrpcTransport(
    ad_group_simulation_service_grpc_transport.AdGroupSimulationServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_parameter_service_grpc_transport as ad_parameter_service_grpc_transport,
)

class AdParameterServiceGrpcTransport(
    ad_parameter_service_grpc_transport.AdParameterServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_schedule_view_service_grpc_transport as ad_schedule_view_service_grpc_transport,
)

class AdScheduleViewServiceGrpcTransport(
    ad_schedule_view_service_grpc_transport.AdScheduleViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    ad_service_grpc_transport as ad_service_grpc_transport,
)

class AdServiceGrpcTransport(ad_service_grpc_transport.AdServiceGrpcTransport): ...

from google.ads.google_ads.v3.services.transports import (
    age_range_view_service_grpc_transport as age_range_view_service_grpc_transport,
)

class AgeRangeViewServiceGrpcTransport(
    age_range_view_service_grpc_transport.AgeRangeViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    asset_service_grpc_transport as asset_service_grpc_transport,
)

class AssetServiceGrpcTransport(
    asset_service_grpc_transport.AssetServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    bidding_strategy_service_grpc_transport as bidding_strategy_service_grpc_transport,
)

class BiddingStrategyServiceGrpcTransport(
    bidding_strategy_service_grpc_transport.BiddingStrategyServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    billing_setup_service_grpc_transport as billing_setup_service_grpc_transport,
)

class BillingSetupServiceGrpcTransport(
    billing_setup_service_grpc_transport.BillingSetupServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    campaign_audience_view_service_grpc_transport as campaign_audience_view_service_grpc_transport,
)

class CampaignAudienceViewServiceGrpcTransport(
    campaign_audience_view_service_grpc_transport.CampaignAudienceViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    campaign_bid_modifier_service_grpc_transport as campaign_bid_modifier_service_grpc_transport,
)

class CampaignBidModifierServiceGrpcTransport(
    campaign_bid_modifier_service_grpc_transport.CampaignBidModifierServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    campaign_budget_service_grpc_transport as campaign_budget_service_grpc_transport,
)

class CampaignBudgetServiceGrpcTransport(
    campaign_budget_service_grpc_transport.CampaignBudgetServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    campaign_criterion_service_grpc_transport as campaign_criterion_service_grpc_transport,
)

class CampaignCriterionServiceGrpcTransport(
    campaign_criterion_service_grpc_transport.CampaignCriterionServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    campaign_criterion_simulation_service_grpc_transport as campaign_criterion_simulation_service_grpc_transport,
)

class CampaignCriterionSimulationServiceGrpcTransport(
    campaign_criterion_simulation_service_grpc_transport.CampaignCriterionSimulationServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    campaign_draft_service_grpc_transport as campaign_draft_service_grpc_transport,
)

class CampaignDraftServiceGrpcTransport(
    campaign_draft_service_grpc_transport.CampaignDraftServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    campaign_experiment_service_grpc_transport as campaign_experiment_service_grpc_transport,
)

class CampaignExperimentServiceGrpcTransport(
    campaign_experiment_service_grpc_transport.CampaignExperimentServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    campaign_extension_setting_service_grpc_transport as campaign_extension_setting_service_grpc_transport,
)

class CampaignExtensionSettingServiceGrpcTransport(
    campaign_extension_setting_service_grpc_transport.CampaignExtensionSettingServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    campaign_feed_service_grpc_transport as campaign_feed_service_grpc_transport,
)

class CampaignFeedServiceGrpcTransport(
    campaign_feed_service_grpc_transport.CampaignFeedServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    campaign_label_service_grpc_transport as campaign_label_service_grpc_transport,
)

class CampaignLabelServiceGrpcTransport(
    campaign_label_service_grpc_transport.CampaignLabelServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    campaign_service_grpc_transport as campaign_service_grpc_transport,
)

class CampaignServiceGrpcTransport(
    campaign_service_grpc_transport.CampaignServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    campaign_shared_set_service_grpc_transport as campaign_shared_set_service_grpc_transport,
)

class CampaignSharedSetServiceGrpcTransport(
    campaign_shared_set_service_grpc_transport.CampaignSharedSetServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    carrier_constant_service_grpc_transport as carrier_constant_service_grpc_transport,
)

class CarrierConstantServiceGrpcTransport(
    carrier_constant_service_grpc_transport.CarrierConstantServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    change_status_service_grpc_transport as change_status_service_grpc_transport,
)

class ChangeStatusServiceGrpcTransport(
    change_status_service_grpc_transport.ChangeStatusServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    click_view_service_grpc_transport as click_view_service_grpc_transport,
)

class ClickViewServiceGrpcTransport(
    click_view_service_grpc_transport.ClickViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    conversion_action_service_grpc_transport as conversion_action_service_grpc_transport,
)

class ConversionActionServiceGrpcTransport(
    conversion_action_service_grpc_transport.ConversionActionServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    conversion_adjustment_upload_service_grpc_transport as conversion_adjustment_upload_service_grpc_transport,
)

class ConversionAdjustmentUploadServiceGrpcTransport(
    conversion_adjustment_upload_service_grpc_transport.ConversionAdjustmentUploadServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    conversion_upload_service_grpc_transport as conversion_upload_service_grpc_transport,
)

class ConversionUploadServiceGrpcTransport(
    conversion_upload_service_grpc_transport.ConversionUploadServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    currency_constant_service_grpc_transport as currency_constant_service_grpc_transport,
)

class CurrencyConstantServiceGrpcTransport(
    currency_constant_service_grpc_transport.CurrencyConstantServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    custom_interest_service_grpc_transport as custom_interest_service_grpc_transport,
)

class CustomInterestServiceGrpcTransport(
    custom_interest_service_grpc_transport.CustomInterestServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    customer_client_link_service_grpc_transport as customer_client_link_service_grpc_transport,
)

class CustomerClientLinkServiceGrpcTransport(
    customer_client_link_service_grpc_transport.CustomerClientLinkServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    customer_client_service_grpc_transport as customer_client_service_grpc_transport,
)

class CustomerClientServiceGrpcTransport(
    customer_client_service_grpc_transport.CustomerClientServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    customer_extension_setting_service_grpc_transport as customer_extension_setting_service_grpc_transport,
)

class CustomerExtensionSettingServiceGrpcTransport(
    customer_extension_setting_service_grpc_transport.CustomerExtensionSettingServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    customer_feed_service_grpc_transport as customer_feed_service_grpc_transport,
)

class CustomerFeedServiceGrpcTransport(
    customer_feed_service_grpc_transport.CustomerFeedServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    customer_label_service_grpc_transport as customer_label_service_grpc_transport,
)

class CustomerLabelServiceGrpcTransport(
    customer_label_service_grpc_transport.CustomerLabelServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    customer_manager_link_service_grpc_transport as customer_manager_link_service_grpc_transport,
)

class CustomerManagerLinkServiceGrpcTransport(
    customer_manager_link_service_grpc_transport.CustomerManagerLinkServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    customer_negative_criterion_service_grpc_transport as customer_negative_criterion_service_grpc_transport,
)

class CustomerNegativeCriterionServiceGrpcTransport(
    customer_negative_criterion_service_grpc_transport.CustomerNegativeCriterionServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    customer_service_grpc_transport as customer_service_grpc_transport,
)

class CustomerServiceGrpcTransport(
    customer_service_grpc_transport.CustomerServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    detail_placement_view_service_grpc_transport as detail_placement_view_service_grpc_transport,
)

class DetailPlacementViewServiceGrpcTransport(
    detail_placement_view_service_grpc_transport.DetailPlacementViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    display_keyword_view_service_grpc_transport as display_keyword_view_service_grpc_transport,
)

class DisplayKeywordViewServiceGrpcTransport(
    display_keyword_view_service_grpc_transport.DisplayKeywordViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    distance_view_service_grpc_transport as distance_view_service_grpc_transport,
)

class DistanceViewServiceGrpcTransport(
    distance_view_service_grpc_transport.DistanceViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    domain_category_service_grpc_transport as domain_category_service_grpc_transport,
)

class DomainCategoryServiceGrpcTransport(
    domain_category_service_grpc_transport.DomainCategoryServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    dynamic_search_ads_search_term_view_service_grpc_transport as dynamic_search_ads_search_term_view_service_grpc_transport,
)

class DynamicSearchAdsSearchTermViewServiceGrpcTransport(
    dynamic_search_ads_search_term_view_service_grpc_transport.DynamicSearchAdsSearchTermViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    expanded_landing_page_view_service_grpc_transport as expanded_landing_page_view_service_grpc_transport,
)

class ExpandedLandingPageViewServiceGrpcTransport(
    expanded_landing_page_view_service_grpc_transport.ExpandedLandingPageViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    extension_feed_item_service_grpc_transport as extension_feed_item_service_grpc_transport,
)

class ExtensionFeedItemServiceGrpcTransport(
    extension_feed_item_service_grpc_transport.ExtensionFeedItemServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    feed_item_service_grpc_transport as feed_item_service_grpc_transport,
)

class FeedItemServiceGrpcTransport(
    feed_item_service_grpc_transport.FeedItemServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    feed_item_target_service_grpc_transport as feed_item_target_service_grpc_transport,
)

class FeedItemTargetServiceGrpcTransport(
    feed_item_target_service_grpc_transport.FeedItemTargetServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    feed_mapping_service_grpc_transport as feed_mapping_service_grpc_transport,
)

class FeedMappingServiceGrpcTransport(
    feed_mapping_service_grpc_transport.FeedMappingServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    feed_placeholder_view_service_grpc_transport as feed_placeholder_view_service_grpc_transport,
)

class FeedPlaceholderViewServiceGrpcTransport(
    feed_placeholder_view_service_grpc_transport.FeedPlaceholderViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    feed_service_grpc_transport as feed_service_grpc_transport,
)

class FeedServiceGrpcTransport(
    feed_service_grpc_transport.FeedServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    gender_view_service_grpc_transport as gender_view_service_grpc_transport,
)

class GenderViewServiceGrpcTransport(
    gender_view_service_grpc_transport.GenderViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    geo_target_constant_service_grpc_transport as geo_target_constant_service_grpc_transport,
)

class GeoTargetConstantServiceGrpcTransport(
    geo_target_constant_service_grpc_transport.GeoTargetConstantServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    geographic_view_service_grpc_transport as geographic_view_service_grpc_transport,
)

class GeographicViewServiceGrpcTransport(
    geographic_view_service_grpc_transport.GeographicViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    google_ads_field_service_grpc_transport as google_ads_field_service_grpc_transport,
)

class GoogleAdsFieldServiceGrpcTransport(
    google_ads_field_service_grpc_transport.GoogleAdsFieldServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    google_ads_service_grpc_transport as google_ads_service_grpc_transport,
)

class GoogleAdsServiceGrpcTransport(
    google_ads_service_grpc_transport.GoogleAdsServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    group_placement_view_service_grpc_transport as group_placement_view_service_grpc_transport,
)

class GroupPlacementViewServiceGrpcTransport(
    group_placement_view_service_grpc_transport.GroupPlacementViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    hotel_group_view_service_grpc_transport as hotel_group_view_service_grpc_transport,
)

class HotelGroupViewServiceGrpcTransport(
    hotel_group_view_service_grpc_transport.HotelGroupViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    hotel_performance_view_service_grpc_transport as hotel_performance_view_service_grpc_transport,
)

class HotelPerformanceViewServiceGrpcTransport(
    hotel_performance_view_service_grpc_transport.HotelPerformanceViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    invoice_service_grpc_transport as invoice_service_grpc_transport,
)

class InvoiceServiceGrpcTransport(
    invoice_service_grpc_transport.InvoiceServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    keyword_plan_ad_group_service_grpc_transport as keyword_plan_ad_group_service_grpc_transport,
)

class KeywordPlanAdGroupServiceGrpcTransport(
    keyword_plan_ad_group_service_grpc_transport.KeywordPlanAdGroupServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    keyword_plan_campaign_service_grpc_transport as keyword_plan_campaign_service_grpc_transport,
)

class KeywordPlanCampaignServiceGrpcTransport(
    keyword_plan_campaign_service_grpc_transport.KeywordPlanCampaignServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    keyword_plan_idea_service_grpc_transport as keyword_plan_idea_service_grpc_transport,
)

class KeywordPlanIdeaServiceGrpcTransport(
    keyword_plan_idea_service_grpc_transport.KeywordPlanIdeaServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    keyword_plan_keyword_service_grpc_transport as keyword_plan_keyword_service_grpc_transport,
)

class KeywordPlanKeywordServiceGrpcTransport(
    keyword_plan_keyword_service_grpc_transport.KeywordPlanKeywordServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    keyword_plan_negative_keyword_service_grpc_transport as keyword_plan_negative_keyword_service_grpc_transport,
)

class KeywordPlanNegativeKeywordServiceGrpcTransport(
    keyword_plan_negative_keyword_service_grpc_transport.KeywordPlanNegativeKeywordServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    keyword_plan_service_grpc_transport as keyword_plan_service_grpc_transport,
)

class KeywordPlanServiceGrpcTransport(
    keyword_plan_service_grpc_transport.KeywordPlanServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    keyword_view_service_grpc_transport as keyword_view_service_grpc_transport,
)

class KeywordViewServiceGrpcTransport(
    keyword_view_service_grpc_transport.KeywordViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    label_service_grpc_transport as label_service_grpc_transport,
)

class LabelServiceGrpcTransport(
    label_service_grpc_transport.LabelServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    landing_page_view_service_grpc_transport as landing_page_view_service_grpc_transport,
)

class LandingPageViewServiceGrpcTransport(
    landing_page_view_service_grpc_transport.LandingPageViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    language_constant_service_grpc_transport as language_constant_service_grpc_transport,
)

class LanguageConstantServiceGrpcTransport(
    language_constant_service_grpc_transport.LanguageConstantServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    location_view_service_grpc_transport as location_view_service_grpc_transport,
)

class LocationViewServiceGrpcTransport(
    location_view_service_grpc_transport.LocationViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    managed_placement_view_service_grpc_transport as managed_placement_view_service_grpc_transport,
)

class ManagedPlacementViewServiceGrpcTransport(
    managed_placement_view_service_grpc_transport.ManagedPlacementViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    media_file_service_grpc_transport as media_file_service_grpc_transport,
)

class MediaFileServiceGrpcTransport(
    media_file_service_grpc_transport.MediaFileServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    merchant_center_link_service_grpc_transport as merchant_center_link_service_grpc_transport,
)

class MerchantCenterLinkServiceGrpcTransport(
    merchant_center_link_service_grpc_transport.MerchantCenterLinkServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    mobile_app_category_constant_service_grpc_transport as mobile_app_category_constant_service_grpc_transport,
)

class MobileAppCategoryConstantServiceGrpcTransport(
    mobile_app_category_constant_service_grpc_transport.MobileAppCategoryConstantServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    mobile_device_constant_service_grpc_transport as mobile_device_constant_service_grpc_transport,
)

class MobileDeviceConstantServiceGrpcTransport(
    mobile_device_constant_service_grpc_transport.MobileDeviceConstantServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    mutate_job_service_grpc_transport as mutate_job_service_grpc_transport,
)

class MutateJobServiceGrpcTransport(
    mutate_job_service_grpc_transport.MutateJobServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    offline_user_data_job_service_grpc_transport as offline_user_data_job_service_grpc_transport,
)

class OfflineUserDataJobServiceGrpcTransport(
    offline_user_data_job_service_grpc_transport.OfflineUserDataJobServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    operating_system_version_constant_service_grpc_transport as operating_system_version_constant_service_grpc_transport,
)

class OperatingSystemVersionConstantServiceGrpcTransport(
    operating_system_version_constant_service_grpc_transport.OperatingSystemVersionConstantServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    paid_organic_search_term_view_service_grpc_transport as paid_organic_search_term_view_service_grpc_transport,
)

class PaidOrganicSearchTermViewServiceGrpcTransport(
    paid_organic_search_term_view_service_grpc_transport.PaidOrganicSearchTermViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    parental_status_view_service_grpc_transport as parental_status_view_service_grpc_transport,
)

class ParentalStatusViewServiceGrpcTransport(
    parental_status_view_service_grpc_transport.ParentalStatusViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    payments_account_service_grpc_transport as payments_account_service_grpc_transport,
)

class PaymentsAccountServiceGrpcTransport(
    payments_account_service_grpc_transport.PaymentsAccountServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    product_bidding_category_constant_service_grpc_transport as product_bidding_category_constant_service_grpc_transport,
)

class ProductBiddingCategoryConstantServiceGrpcTransport(
    product_bidding_category_constant_service_grpc_transport.ProductBiddingCategoryConstantServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    product_group_view_service_grpc_transport as product_group_view_service_grpc_transport,
)

class ProductGroupViewServiceGrpcTransport(
    product_group_view_service_grpc_transport.ProductGroupViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    reach_plan_service_grpc_transport as reach_plan_service_grpc_transport,
)

class ReachPlanServiceGrpcTransport(
    reach_plan_service_grpc_transport.ReachPlanServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    recommendation_service_grpc_transport as recommendation_service_grpc_transport,
)

class RecommendationServiceGrpcTransport(
    recommendation_service_grpc_transport.RecommendationServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    remarketing_action_service_grpc_transport as remarketing_action_service_grpc_transport,
)

class RemarketingActionServiceGrpcTransport(
    remarketing_action_service_grpc_transport.RemarketingActionServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    search_term_view_service_grpc_transport as search_term_view_service_grpc_transport,
)

class SearchTermViewServiceGrpcTransport(
    search_term_view_service_grpc_transport.SearchTermViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    shared_criterion_service_grpc_transport as shared_criterion_service_grpc_transport,
)

class SharedCriterionServiceGrpcTransport(
    shared_criterion_service_grpc_transport.SharedCriterionServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    shared_set_service_grpc_transport as shared_set_service_grpc_transport,
)

class SharedSetServiceGrpcTransport(
    shared_set_service_grpc_transport.SharedSetServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    shopping_performance_view_service_grpc_transport as shopping_performance_view_service_grpc_transport,
)

class ShoppingPerformanceViewServiceGrpcTransport(
    shopping_performance_view_service_grpc_transport.ShoppingPerformanceViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    topic_constant_service_grpc_transport as topic_constant_service_grpc_transport,
)

class TopicConstantServiceGrpcTransport(
    topic_constant_service_grpc_transport.TopicConstantServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    topic_view_service_grpc_transport as topic_view_service_grpc_transport,
)

class TopicViewServiceGrpcTransport(
    topic_view_service_grpc_transport.TopicViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    user_data_service_grpc_transport as user_data_service_grpc_transport,
)

class UserDataServiceGrpcTransport(
    user_data_service_grpc_transport.UserDataServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    user_interest_service_grpc_transport as user_interest_service_grpc_transport,
)

class UserInterestServiceGrpcTransport(
    user_interest_service_grpc_transport.UserInterestServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    user_list_service_grpc_transport as user_list_service_grpc_transport,
)

class UserListServiceGrpcTransport(
    user_list_service_grpc_transport.UserListServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    user_location_view_service_grpc_transport as user_location_view_service_grpc_transport,
)

class UserLocationViewServiceGrpcTransport(
    user_location_view_service_grpc_transport.UserLocationViewServiceGrpcTransport
): ...

from google.ads.google_ads.v3.services.transports import (
    video_service_grpc_transport as video_service_grpc_transport,
)

class VideoServiceGrpcTransport(
    video_service_grpc_transport.VideoServiceGrpcTransport
): ...

__all__ = [
    "AccountBudgetProposalServiceClient",
    "AccountBudgetServiceClient",
    "AdGroupAdAssetViewServiceClient",
    "AdGroupAdLabelServiceClient",
    "AdGroupAdServiceClient",
    "AdGroupAudienceViewServiceClient",
    "AdGroupBidModifierServiceClient",
    "AdGroupCriterionLabelServiceClient",
    "AdGroupCriterionServiceClient",
    "AdGroupCriterionSimulationServiceClient",
    "AdGroupExtensionSettingServiceClient",
    "AdGroupFeedServiceClient",
    "AdGroupLabelServiceClient",
    "AdGroupServiceClient",
    "AdGroupSimulationServiceClient",
    "AdParameterServiceClient",
    "AdScheduleViewServiceClient",
    "AdServiceClient",
    "AgeRangeViewServiceClient",
    "AssetServiceClient",
    "BiddingStrategyServiceClient",
    "BillingSetupServiceClient",
    "CampaignAudienceViewServiceClient",
    "CampaignBidModifierServiceClient",
    "CampaignBudgetServiceClient",
    "CampaignCriterionServiceClient",
    "CampaignCriterionSimulationServiceClient",
    "CampaignDraftServiceClient",
    "CampaignExperimentServiceClient",
    "CampaignExtensionSettingServiceClient",
    "CampaignFeedServiceClient",
    "CampaignLabelServiceClient",
    "CampaignServiceClient",
    "CampaignSharedSetServiceClient",
    "CarrierConstantServiceClient",
    "ChangeStatusServiceClient",
    "ClickViewServiceClient",
    "ConversionActionServiceClient",
    "ConversionAdjustmentUploadServiceClient",
    "ConversionUploadServiceClient",
    "CurrencyConstantServiceClient",
    "CustomInterestServiceClient",
    "CustomerClientLinkServiceClient",
    "CustomerClientServiceClient",
    "CustomerExtensionSettingServiceClient",
    "CustomerFeedServiceClient",
    "CustomerLabelServiceClient",
    "CustomerManagerLinkServiceClient",
    "CustomerNegativeCriterionServiceClient",
    "CustomerServiceClient",
    "DetailPlacementViewServiceClient",
    "DisplayKeywordViewServiceClient",
    "DistanceViewServiceClient",
    "DomainCategoryServiceClient",
    "DynamicSearchAdsSearchTermViewServiceClient",
    "ExpandedLandingPageViewServiceClient",
    "ExtensionFeedItemServiceClient",
    "FeedItemServiceClient",
    "FeedItemTargetServiceClient",
    "FeedMappingServiceClient",
    "FeedPlaceholderViewServiceClient",
    "FeedServiceClient",
    "GenderViewServiceClient",
    "GeoTargetConstantServiceClient",
    "GeographicViewServiceClient",
    "GoogleAdsFieldServiceClient",
    "GoogleAdsServiceClient",
    "GroupPlacementViewServiceClient",
    "HotelGroupViewServiceClient",
    "HotelPerformanceViewServiceClient",
    "InvoiceServiceClient",
    "KeywordPlanAdGroupServiceClient",
    "KeywordPlanCampaignServiceClient",
    "KeywordPlanIdeaServiceClient",
    "KeywordPlanKeywordServiceClient",
    "KeywordPlanNegativeKeywordServiceClient",
    "KeywordPlanServiceClient",
    "KeywordViewServiceClient",
    "LabelServiceClient",
    "LandingPageViewServiceClient",
    "LanguageConstantServiceClient",
    "LocationViewServiceClient",
    "ManagedPlacementViewServiceClient",
    "MediaFileServiceClient",
    "MerchantCenterLinkServiceClient",
    "MobileAppCategoryConstantServiceClient",
    "MobileDeviceConstantServiceClient",
    "MutateJobServiceClient",
    "OfflineUserDataJobServiceClient",
    "OperatingSystemVersionConstantServiceClient",
    "PaidOrganicSearchTermViewServiceClient",
    "ParentalStatusViewServiceClient",
    "PaymentsAccountServiceClient",
    "ProductBiddingCategoryConstantServiceClient",
    "ProductGroupViewServiceClient",
    "ReachPlanServiceClient",
    "RecommendationServiceClient",
    "RemarketingActionServiceClient",
    "SearchTermViewServiceClient",
    "SharedCriterionServiceClient",
    "SharedSetServiceClient",
    "ShoppingPerformanceViewServiceClient",
    "TopicConstantServiceClient",
    "TopicViewServiceClient",
    "UserDataServiceClient",
    "UserInterestServiceClient",
    "UserListServiceClient",
    "UserLocationViewServiceClient",
    "VideoServiceClient",
    "AccountBudgetProposalServiceGrpcTransport",
    "AccountBudgetServiceGrpcTransport",
    "AdGroupAdAssetViewServiceGrpcTransport",
    "AdGroupAdLabelServiceGrpcTransport",
    "AdGroupAdServiceGrpcTransport",
    "AdGroupAudienceViewServiceGrpcTransport",
    "AdGroupBidModifierServiceGrpcTransport",
    "AdGroupCriterionLabelServiceGrpcTransport",
    "AdGroupCriterionServiceGrpcTransport",
    "AdGroupCriterionSimulationServiceGrpcTransport",
    "AdGroupExtensionSettingServiceGrpcTransport",
    "AdGroupFeedServiceGrpcTransport",
    "AdGroupLabelServiceGrpcTransport",
    "AdGroupServiceGrpcTransport",
    "AdGroupSimulationServiceGrpcTransport",
    "AdParameterServiceGrpcTransport",
    "AdScheduleViewServiceGrpcTransport",
    "AdServiceGrpcTransport",
    "AgeRangeViewServiceGrpcTransport",
    "AssetServiceGrpcTransport",
    "BiddingStrategyServiceGrpcTransport",
    "BillingSetupServiceGrpcTransport",
    "CampaignAudienceViewServiceGrpcTransport",
    "CampaignBidModifierServiceGrpcTransport",
    "CampaignBudgetServiceGrpcTransport",
    "CampaignCriterionServiceGrpcTransport",
    "CampaignCriterionSimulationServiceGrpcTransport",
    "CampaignDraftServiceGrpcTransport",
    "CampaignExperimentServiceGrpcTransport",
    "CampaignExtensionSettingServiceGrpcTransport",
    "CampaignFeedServiceGrpcTransport",
    "CampaignLabelServiceGrpcTransport",
    "CampaignServiceGrpcTransport",
    "CampaignSharedSetServiceGrpcTransport",
    "CarrierConstantServiceGrpcTransport",
    "ChangeStatusServiceGrpcTransport",
    "ClickViewServiceGrpcTransport",
    "ConversionActionServiceGrpcTransport",
    "ConversionAdjustmentUploadServiceGrpcTransport",
    "ConversionUploadServiceGrpcTransport",
    "CurrencyConstantServiceGrpcTransport",
    "CustomInterestServiceGrpcTransport",
    "CustomerClientLinkServiceGrpcTransport",
    "CustomerClientServiceGrpcTransport",
    "CustomerExtensionSettingServiceGrpcTransport",
    "CustomerFeedServiceGrpcTransport",
    "CustomerLabelServiceGrpcTransport",
    "CustomerManagerLinkServiceGrpcTransport",
    "CustomerNegativeCriterionServiceGrpcTransport",
    "CustomerServiceGrpcTransport",
    "DetailPlacementViewServiceGrpcTransport",
    "DisplayKeywordViewServiceGrpcTransport",
    "DistanceViewServiceGrpcTransport",
    "DomainCategoryServiceGrpcTransport",
    "DynamicSearchAdsSearchTermViewServiceGrpcTransport",
    "ExpandedLandingPageViewServiceGrpcTransport",
    "ExtensionFeedItemServiceGrpcTransport",
    "FeedItemServiceGrpcTransport",
    "FeedItemTargetServiceGrpcTransport",
    "FeedMappingServiceGrpcTransport",
    "FeedPlaceholderViewServiceGrpcTransport",
    "FeedServiceGrpcTransport",
    "GenderViewServiceGrpcTransport",
    "GeoTargetConstantServiceGrpcTransport",
    "GeographicViewServiceGrpcTransport",
    "GoogleAdsFieldServiceGrpcTransport",
    "GoogleAdsServiceGrpcTransport",
    "GroupPlacementViewServiceGrpcTransport",
    "HotelGroupViewServiceGrpcTransport",
    "HotelPerformanceViewServiceGrpcTransport",
    "InvoiceServiceGrpcTransport",
    "KeywordPlanAdGroupServiceGrpcTransport",
    "KeywordPlanCampaignServiceGrpcTransport",
    "KeywordPlanIdeaServiceGrpcTransport",
    "KeywordPlanKeywordServiceGrpcTransport",
    "KeywordPlanNegativeKeywordServiceGrpcTransport",
    "KeywordPlanServiceGrpcTransport",
    "KeywordViewServiceGrpcTransport",
    "LabelServiceGrpcTransport",
    "LandingPageViewServiceGrpcTransport",
    "LanguageConstantServiceGrpcTransport",
    "LocationViewServiceGrpcTransport",
    "ManagedPlacementViewServiceGrpcTransport",
    "MediaFileServiceGrpcTransport",
    "MerchantCenterLinkServiceGrpcTransport",
    "MobileAppCategoryConstantServiceGrpcTransport",
    "MobileDeviceConstantServiceGrpcTransport",
    "MutateJobServiceGrpcTransport",
    "OfflineUserDataJobServiceGrpcTransport",
    "OperatingSystemVersionConstantServiceGrpcTransport",
    "PaidOrganicSearchTermViewServiceGrpcTransport",
    "ParentalStatusViewServiceGrpcTransport",
    "PaymentsAccountServiceGrpcTransport",
    "ProductBiddingCategoryConstantServiceGrpcTransport",
    "ProductGroupViewServiceGrpcTransport",
    "ReachPlanServiceGrpcTransport",
    "RecommendationServiceGrpcTransport",
    "RemarketingActionServiceGrpcTransport",
    "SearchTermViewServiceGrpcTransport",
    "SharedCriterionServiceGrpcTransport",
    "SharedSetServiceGrpcTransport",
    "ShoppingPerformanceViewServiceGrpcTransport",
    "TopicConstantServiceGrpcTransport",
    "TopicViewServiceGrpcTransport",
    "UserDataServiceGrpcTransport",
    "UserInterestServiceGrpcTransport",
    "UserListServiceGrpcTransport",
    "UserLocationViewServiceGrpcTransport",
    "VideoServiceGrpcTransport",
]



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CurrencyConstant(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    code: typing___Text = ...
    name: typing___Text = ...
    symbol: typing___Text = ...
    billable_unit_micros: builtin___int = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        code: typing___Optional[typing___Text] = None,
        name: typing___Optional[typing___Text] = None,
        symbol: typing___Optional[typing___Text] = None,
        billable_unit_micros: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_billable_unit_micros",
            b"_billable_unit_micros",
            "_code",
            b"_code",
            "_name",
            b"_name",
            "_symbol",
            b"_symbol",
            "billable_unit_micros",
            b"billable_unit_micros",
            "code",
            b"code",
            "name",
            b"name",
            "symbol",
            b"symbol",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_billable_unit_micros",
            b"_billable_unit_micros",
            "_code",
            b"_code",
            "_name",
            b"_name",
            "_symbol",
            b"_symbol",
            "billable_unit_micros",
            b"billable_unit_micros",
            "code",
            b"code",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "symbol",
            b"symbol",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_billable_unit_micros", b"_billable_unit_micros"
        ],
    ) -> typing_extensions___Literal["billable_unit_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_code", b"_code"]
    ) -> typing_extensions___Literal["code"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_symbol", b"_symbol"]
    ) -> typing_extensions___Literal["symbol"]: ...

type___CurrencyConstant = CurrencyConstant



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GoogleAdsFieldDataTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    GoogleAdsFieldDataTypeValue = typing___NewType(
        "GoogleAdsFieldDataTypeValue", builtin___int
    )
    type___GoogleAdsFieldDataTypeValue = GoogleAdsFieldDataTypeValue
    GoogleAdsFieldDataType: _GoogleAdsFieldDataType
    class _GoogleAdsFieldDataType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 0
        )
        UNKNOWN = typing___cast(
            GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 1
        )
        BOOLEAN = typing___cast(
            GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 2
        )
        DATE = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 3)
        DOUBLE = typing___cast(
            GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 4
        )
        ENUM = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 5)
        FLOAT = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 6)
        INT32 = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 7)
        INT64 = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 8)
        MESSAGE = typing___cast(
            GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 9
        )
        RESOURCE_NAME = typing___cast(
            GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 10
        )
        STRING = typing___cast(
            GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 11
        )
        UINT64 = typing___cast(
            GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 12
        )
    UNSPECIFIED = typing___cast(
        GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 0
    )
    UNKNOWN = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 1)
    BOOLEAN = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 2)
    DATE = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 3)
    DOUBLE = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 4)
    ENUM = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 5)
    FLOAT = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 6)
    INT32 = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 7)
    INT64 = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 8)
    MESSAGE = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 9)
    RESOURCE_NAME = typing___cast(
        GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 10
    )
    STRING = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 11)
    UINT64 = typing___cast(GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataTypeValue, 12)
    type___GoogleAdsFieldDataType = GoogleAdsFieldDataType
    def __init__(self,) -> None: ...

type___GoogleAdsFieldDataTypeEnum = GoogleAdsFieldDataTypeEnum



from typing import Any

class AdGroupLabelServiceStub:
    GetAdGroupLabel: Any = ...
    MutateAdGroupLabels: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AdGroupLabelServiceServicer:
    def GetAdGroupLabel(self, request: Any, context: Any) -> None: ...
    def MutateAdGroupLabels(self, request: Any, context: Any) -> None: ...

def add_AdGroupLabelServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.criteria_pb2 import (
    AdScheduleInfo as google___ads___googleads___v6___common___criteria_pb2___AdScheduleInfo,
    KeywordInfo as google___ads___googleads___v6___common___criteria_pb2___KeywordInfo,
)
from google.ads.google_ads.v6.proto.enums.feed_item_target_device_pb2 import (
    FeedItemTargetDeviceEnum as google___ads___googleads___v6___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum,
)
from google.ads.google_ads.v6.proto.enums.feed_item_target_status_pb2 import (
    FeedItemTargetStatusEnum as google___ads___googleads___v6___enums___feed_item_target_status_pb2___FeedItemTargetStatusEnum,
)
from google.ads.google_ads.v6.proto.enums.feed_item_target_type_pb2 import (
    FeedItemTargetTypeEnum as google___ads___googleads___v6___enums___feed_item_target_type_pb2___FeedItemTargetTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemTarget(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    feed_item: typing___Text = ...
    feed_item_target_type: google___ads___googleads___v6___enums___feed_item_target_type_pb2___FeedItemTargetTypeEnum.FeedItemTargetTypeValue = ...
    feed_item_target_id: builtin___int = ...
    status: google___ads___googleads___v6___enums___feed_item_target_status_pb2___FeedItemTargetStatusEnum.FeedItemTargetStatusValue = ...
    campaign: typing___Text = ...
    ad_group: typing___Text = ...
    geo_target_constant: typing___Text = ...
    device: google___ads___googleads___v6___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue = ...
    @property
    def keyword(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___KeywordInfo: ...
    @property
    def ad_schedule(
        self,
    ) -> google___ads___googleads___v6___common___criteria_pb2___AdScheduleInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        feed_item: typing___Optional[typing___Text] = None,
        feed_item_target_type: typing___Optional[
            google___ads___googleads___v6___enums___feed_item_target_type_pb2___FeedItemTargetTypeEnum.FeedItemTargetTypeValue
        ] = None,
        feed_item_target_id: typing___Optional[builtin___int] = None,
        status: typing___Optional[
            google___ads___googleads___v6___enums___feed_item_target_status_pb2___FeedItemTargetStatusEnum.FeedItemTargetStatusValue
        ] = None,
        campaign: typing___Optional[typing___Text] = None,
        ad_group: typing___Optional[typing___Text] = None,
        keyword: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___KeywordInfo
        ] = None,
        geo_target_constant: typing___Optional[typing___Text] = None,
        device: typing___Optional[
            google___ads___googleads___v6___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum.FeedItemTargetDeviceValue
        ] = None,
        ad_schedule: typing___Optional[
            google___ads___googleads___v6___common___criteria_pb2___AdScheduleInfo
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_feed_item",
            b"_feed_item",
            "_feed_item_target_id",
            b"_feed_item_target_id",
            "ad_group",
            b"ad_group",
            "ad_schedule",
            b"ad_schedule",
            "campaign",
            b"campaign",
            "device",
            b"device",
            "feed_item",
            b"feed_item",
            "feed_item_target_id",
            b"feed_item_target_id",
            "geo_target_constant",
            b"geo_target_constant",
            "keyword",
            b"keyword",
            "target",
            b"target",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_feed_item",
            b"_feed_item",
            "_feed_item_target_id",
            b"_feed_item_target_id",
            "ad_group",
            b"ad_group",
            "ad_schedule",
            b"ad_schedule",
            "campaign",
            b"campaign",
            "device",
            b"device",
            "feed_item",
            b"feed_item",
            "feed_item_target_id",
            b"feed_item_target_id",
            "feed_item_target_type",
            b"feed_item_target_type",
            "geo_target_constant",
            b"geo_target_constant",
            "keyword",
            b"keyword",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "target",
            b"target",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_feed_item", b"_feed_item"]
    ) -> typing_extensions___Literal["feed_item"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_feed_item_target_id", b"_feed_item_target_id"
        ],
    ) -> typing_extensions___Literal["feed_item_target_id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["target", b"target"]
    ) -> typing_extensions___Literal[
        "campaign",
        "ad_group",
        "keyword",
        "geo_target_constant",
        "device",
        "ad_schedule",
    ]: ...

type___FeedItemTarget = FeedItemTarget



from typing import Any

class AccountLinkServiceStub:
    GetAccountLink: Any = ...
    MutateAccountLink: Any = ...
    def __init__(self, channel: Any) -> None: ...

class AccountLinkServiceServicer:
    def GetAccountLink(self, request: Any, context: Any) -> None: ...
    def MutateAccountLink(self, request: Any, context: Any) -> None: ...

def add_AccountLinkServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemQualityDisapprovalReasonEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedItemQualityDisapprovalReasonValue = typing___NewType(
        "FeedItemQualityDisapprovalReasonValue", builtin___int
    )
    type___FeedItemQualityDisapprovalReasonValue = FeedItemQualityDisapprovalReasonValue
    FeedItemQualityDisapprovalReason: _FeedItemQualityDisapprovalReason
    class _FeedItemQualityDisapprovalReason(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            0,
        )
        UNKNOWN = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            1,
        )
        PRICE_TABLE_REPETITIVE_HEADERS = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            2,
        )
        PRICE_TABLE_REPETITIVE_DESCRIPTION = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            3,
        )
        PRICE_TABLE_INCONSISTENT_ROWS = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            4,
        )
        PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            5,
        )
        PRICE_UNSUPPORTED_LANGUAGE = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            6,
        )
        PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            7,
        )
        PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            8,
        )
        PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            9,
        )
        PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            10,
        )
        PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            11,
        )
        PRICE_TABLE_ROW_UNRATEABLE = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            12,
        )
        PRICE_TABLE_ROW_PRICE_INVALID = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            13,
        )
        PRICE_TABLE_ROW_URL_INVALID = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            14,
        )
        PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            15,
        )
        STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            16,
        )
        STRUCTURED_SNIPPETS_REPEATED_VALUES = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            17,
        )
        STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            18,
        )
        STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT = typing___cast(
            FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue,
            19,
        )
    UNSPECIFIED = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 0
    )
    UNKNOWN = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 1
    )
    PRICE_TABLE_REPETITIVE_HEADERS = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 2
    )
    PRICE_TABLE_REPETITIVE_DESCRIPTION = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 3
    )
    PRICE_TABLE_INCONSISTENT_ROWS = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 4
    )
    PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 5
    )
    PRICE_UNSUPPORTED_LANGUAGE = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 6
    )
    PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 7
    )
    PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 8
    )
    PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 9
    )
    PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 10
    )
    PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 11
    )
    PRICE_TABLE_ROW_UNRATEABLE = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 12
    )
    PRICE_TABLE_ROW_PRICE_INVALID = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 13
    )
    PRICE_TABLE_ROW_URL_INVALID = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 14
    )
    PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 15
    )
    STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 16
    )
    STRUCTURED_SNIPPETS_REPEATED_VALUES = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 17
    )
    STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 18
    )
    STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT = typing___cast(
        FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue, 19
    )
    type___FeedItemQualityDisapprovalReason = FeedItemQualityDisapprovalReason
    def __init__(self,) -> None: ...

type___FeedItemQualityDisapprovalReasonEnum = FeedItemQualityDisapprovalReasonEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FunctionParsingErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FunctionParsingErrorValue = typing___NewType(
        "FunctionParsingErrorValue", builtin___int
    )
    type___FunctionParsingErrorValue = FunctionParsingErrorValue
    FunctionParsingError: _FunctionParsingError
    class _FunctionParsingError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FunctionParsingErrorEnum.FunctionParsingErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            FunctionParsingErrorEnum.FunctionParsingErrorValue, 0
        )
        UNKNOWN = typing___cast(FunctionParsingErrorEnum.FunctionParsingErrorValue, 1)
        NO_MORE_INPUT = typing___cast(
            FunctionParsingErrorEnum.FunctionParsingErrorValue, 2
        )
        EXPECTED_CHARACTER = typing___cast(
            FunctionParsingErrorEnum.FunctionParsingErrorValue, 3
        )
        UNEXPECTED_SEPARATOR = typing___cast(
            FunctionParsingErrorEnum.FunctionParsingErrorValue, 4
        )
        UNMATCHED_LEFT_BRACKET = typing___cast(
            FunctionParsingErrorEnum.FunctionParsingErrorValue, 5
        )
        UNMATCHED_RIGHT_BRACKET = typing___cast(
            FunctionParsingErrorEnum.FunctionParsingErrorValue, 6
        )
        TOO_MANY_NESTED_FUNCTIONS = typing___cast(
            FunctionParsingErrorEnum.FunctionParsingErrorValue, 7
        )
        MISSING_RIGHT_HAND_OPERAND = typing___cast(
            FunctionParsingErrorEnum.FunctionParsingErrorValue, 8
        )
        INVALID_OPERATOR_NAME = typing___cast(
            FunctionParsingErrorEnum.FunctionParsingErrorValue, 9
        )
        FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER = typing___cast(
            FunctionParsingErrorEnum.FunctionParsingErrorValue, 10
        )
        NO_OPERANDS = typing___cast(
            FunctionParsingErrorEnum.FunctionParsingErrorValue, 11
        )
        TOO_MANY_OPERANDS = typing___cast(
            FunctionParsingErrorEnum.FunctionParsingErrorValue, 12
        )
    UNSPECIFIED = typing___cast(FunctionParsingErrorEnum.FunctionParsingErrorValue, 0)
    UNKNOWN = typing___cast(FunctionParsingErrorEnum.FunctionParsingErrorValue, 1)
    NO_MORE_INPUT = typing___cast(FunctionParsingErrorEnum.FunctionParsingErrorValue, 2)
    EXPECTED_CHARACTER = typing___cast(
        FunctionParsingErrorEnum.FunctionParsingErrorValue, 3
    )
    UNEXPECTED_SEPARATOR = typing___cast(
        FunctionParsingErrorEnum.FunctionParsingErrorValue, 4
    )
    UNMATCHED_LEFT_BRACKET = typing___cast(
        FunctionParsingErrorEnum.FunctionParsingErrorValue, 5
    )
    UNMATCHED_RIGHT_BRACKET = typing___cast(
        FunctionParsingErrorEnum.FunctionParsingErrorValue, 6
    )
    TOO_MANY_NESTED_FUNCTIONS = typing___cast(
        FunctionParsingErrorEnum.FunctionParsingErrorValue, 7
    )
    MISSING_RIGHT_HAND_OPERAND = typing___cast(
        FunctionParsingErrorEnum.FunctionParsingErrorValue, 8
    )
    INVALID_OPERATOR_NAME = typing___cast(
        FunctionParsingErrorEnum.FunctionParsingErrorValue, 9
    )
    FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER = typing___cast(
        FunctionParsingErrorEnum.FunctionParsingErrorValue, 10
    )
    NO_OPERANDS = typing___cast(FunctionParsingErrorEnum.FunctionParsingErrorValue, 11)
    TOO_MANY_OPERANDS = typing___cast(
        FunctionParsingErrorEnum.FunctionParsingErrorValue, 12
    )
    type___FunctionParsingError = FunctionParsingError
    def __init__(self,) -> None: ...

type___FunctionParsingErrorEnum = FunctionParsingErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ContentLabelTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ContentLabelTypeValue = typing___NewType("ContentLabelTypeValue", builtin___int)
    type___ContentLabelTypeValue = ContentLabelTypeValue
    ContentLabelType: _ContentLabelType
    class _ContentLabelType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ContentLabelTypeEnum.ContentLabelTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 0)
        UNKNOWN = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 1)
        SEXUALLY_SUGGESTIVE = typing___cast(
            ContentLabelTypeEnum.ContentLabelTypeValue, 2
        )
        BELOW_THE_FOLD = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 3)
        PARKED_DOMAIN = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 4)
        JUVENILE = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 6)
        PROFANITY = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 7)
        TRAGEDY = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 8)
        VIDEO = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 9)
        VIDEO_RATING_DV_G = typing___cast(
            ContentLabelTypeEnum.ContentLabelTypeValue, 10
        )
        VIDEO_RATING_DV_PG = typing___cast(
            ContentLabelTypeEnum.ContentLabelTypeValue, 11
        )
        VIDEO_RATING_DV_T = typing___cast(
            ContentLabelTypeEnum.ContentLabelTypeValue, 12
        )
        VIDEO_RATING_DV_MA = typing___cast(
            ContentLabelTypeEnum.ContentLabelTypeValue, 13
        )
        VIDEO_NOT_YET_RATED = typing___cast(
            ContentLabelTypeEnum.ContentLabelTypeValue, 14
        )
        EMBEDDED_VIDEO = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 15)
        LIVE_STREAMING_VIDEO = typing___cast(
            ContentLabelTypeEnum.ContentLabelTypeValue, 16
        )
        SOCIAL_ISSUES = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 17)
    UNSPECIFIED = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 0)
    UNKNOWN = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 1)
    SEXUALLY_SUGGESTIVE = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 2)
    BELOW_THE_FOLD = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 3)
    PARKED_DOMAIN = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 4)
    JUVENILE = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 6)
    PROFANITY = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 7)
    TRAGEDY = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 8)
    VIDEO = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 9)
    VIDEO_RATING_DV_G = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 10)
    VIDEO_RATING_DV_PG = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 11)
    VIDEO_RATING_DV_T = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 12)
    VIDEO_RATING_DV_MA = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 13)
    VIDEO_NOT_YET_RATED = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 14)
    EMBEDDED_VIDEO = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 15)
    LIVE_STREAMING_VIDEO = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 16)
    SOCIAL_ISSUES = typing___cast(ContentLabelTypeEnum.ContentLabelTypeValue, 17)
    type___ContentLabelType = ContentLabelType
    def __init__(self,) -> None: ...

type___ContentLabelTypeEnum = ContentLabelTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.dates_pb2 import (
    DateRange as google___ads___googleads___v6___common___dates_pb2___DateRange,
)
from google.ads.google_ads.v6.proto.enums.keyword_plan_forecast_interval_pb2 import (
    KeywordPlanForecastIntervalEnum as google___ads___googleads___v6___enums___keyword_plan_forecast_interval_pb2___KeywordPlanForecastIntervalEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlan(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: builtin___int = ...
    name: typing___Text = ...
    @property
    def forecast_period(self) -> type___KeywordPlanForecastPeriod: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        name: typing___Optional[typing___Text] = None,
        forecast_period: typing___Optional[type___KeywordPlanForecastPeriod] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_id",
            b"_id",
            "_name",
            b"_name",
            "forecast_period",
            b"forecast_period",
            "id",
            b"id",
            "name",
            b"name",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_id",
            b"_id",
            "_name",
            b"_name",
            "forecast_period",
            b"forecast_period",
            "id",
            b"id",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...

type___KeywordPlan = KeywordPlan

class KeywordPlanForecastPeriod(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    date_interval: google___ads___googleads___v6___enums___keyword_plan_forecast_interval_pb2___KeywordPlanForecastIntervalEnum.KeywordPlanForecastIntervalValue = ...
    @property
    def date_range(
        self,
    ) -> google___ads___googleads___v6___common___dates_pb2___DateRange: ...
    def __init__(
        self,
        *,
        date_interval: typing___Optional[
            google___ads___googleads___v6___enums___keyword_plan_forecast_interval_pb2___KeywordPlanForecastIntervalEnum.KeywordPlanForecastIntervalValue
        ] = None,
        date_range: typing___Optional[
            google___ads___googleads___v6___common___dates_pb2___DateRange
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "date_interval",
            b"date_interval",
            "date_range",
            b"date_range",
            "interval",
            b"interval",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "date_interval",
            b"date_interval",
            "date_range",
            b"date_range",
            "interval",
            b"interval",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["interval", b"interval"]
    ) -> typing_extensions___Literal["date_interval", "date_range"]: ...

type___KeywordPlanForecastPeriod = KeywordPlanForecastPeriod



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.account_budget_proposal_type_pb2 import (
    AccountBudgetProposalTypeEnum as google___ads___googleads___v5___enums___account_budget_proposal_type_pb2___AccountBudgetProposalTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.account_budget_status_pb2 import (
    AccountBudgetStatusEnum as google___ads___googleads___v5___enums___account_budget_status_pb2___AccountBudgetStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.spending_limit_type_pb2 import (
    SpendingLimitTypeEnum as google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.time_type_pb2 import (
    TimeTypeEnum as google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AccountBudget(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class PendingAccountBudgetProposal(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        account_budget_proposal: typing___Text = ...
        proposal_type: google___ads___googleads___v5___enums___account_budget_proposal_type_pb2___AccountBudgetProposalTypeEnum.AccountBudgetProposalTypeValue = ...
        name: typing___Text = ...
        start_date_time: typing___Text = ...
        purchase_order_number: typing___Text = ...
        notes: typing___Text = ...
        creation_date_time: typing___Text = ...
        end_date_time: typing___Text = ...
        end_time_type: google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue = ...
        spending_limit_micros: builtin___int = ...
        spending_limit_type: google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue = ...
        def __init__(
            self,
            *,
            account_budget_proposal: typing___Optional[typing___Text] = None,
            proposal_type: typing___Optional[
                google___ads___googleads___v5___enums___account_budget_proposal_type_pb2___AccountBudgetProposalTypeEnum.AccountBudgetProposalTypeValue
            ] = None,
            name: typing___Optional[typing___Text] = None,
            start_date_time: typing___Optional[typing___Text] = None,
            purchase_order_number: typing___Optional[typing___Text] = None,
            notes: typing___Optional[typing___Text] = None,
            creation_date_time: typing___Optional[typing___Text] = None,
            end_date_time: typing___Optional[typing___Text] = None,
            end_time_type: typing___Optional[
                google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue
            ] = None,
            spending_limit_micros: typing___Optional[builtin___int] = None,
            spending_limit_type: typing___Optional[
                google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "_account_budget_proposal",
                b"_account_budget_proposal",
                "_creation_date_time",
                b"_creation_date_time",
                "_name",
                b"_name",
                "_notes",
                b"_notes",
                "_purchase_order_number",
                b"_purchase_order_number",
                "_start_date_time",
                b"_start_date_time",
                "account_budget_proposal",
                b"account_budget_proposal",
                "creation_date_time",
                b"creation_date_time",
                "end_date_time",
                b"end_date_time",
                "end_time",
                b"end_time",
                "end_time_type",
                b"end_time_type",
                "name",
                b"name",
                "notes",
                b"notes",
                "purchase_order_number",
                b"purchase_order_number",
                "spending_limit",
                b"spending_limit",
                "spending_limit_micros",
                b"spending_limit_micros",
                "spending_limit_type",
                b"spending_limit_type",
                "start_date_time",
                b"start_date_time",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "_account_budget_proposal",
                b"_account_budget_proposal",
                "_creation_date_time",
                b"_creation_date_time",
                "_name",
                b"_name",
                "_notes",
                b"_notes",
                "_purchase_order_number",
                b"_purchase_order_number",
                "_start_date_time",
                b"_start_date_time",
                "account_budget_proposal",
                b"account_budget_proposal",
                "creation_date_time",
                b"creation_date_time",
                "end_date_time",
                b"end_date_time",
                "end_time",
                b"end_time",
                "end_time_type",
                b"end_time_type",
                "name",
                b"name",
                "notes",
                b"notes",
                "proposal_type",
                b"proposal_type",
                "purchase_order_number",
                b"purchase_order_number",
                "spending_limit",
                b"spending_limit",
                "spending_limit_micros",
                b"spending_limit_micros",
                "spending_limit_type",
                b"spending_limit_type",
                "start_date_time",
                b"start_date_time",
            ],
        ) -> None: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_account_budget_proposal", b"_account_budget_proposal"
            ],
        ) -> typing_extensions___Literal["account_budget_proposal"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_creation_date_time", b"_creation_date_time"
            ],
        ) -> typing_extensions___Literal["creation_date_time"]: ...
        @typing___overload
        def WhichOneof(
            self, oneof_group: typing_extensions___Literal["_name", b"_name"]
        ) -> typing_extensions___Literal["name"]: ...
        @typing___overload
        def WhichOneof(
            self, oneof_group: typing_extensions___Literal["_notes", b"_notes"]
        ) -> typing_extensions___Literal["notes"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_purchase_order_number", b"_purchase_order_number"
            ],
        ) -> typing_extensions___Literal["purchase_order_number"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "_start_date_time", b"_start_date_time"
            ],
        ) -> typing_extensions___Literal["start_date_time"]: ...
        @typing___overload
        def WhichOneof(
            self, oneof_group: typing_extensions___Literal["end_time", b"end_time"]
        ) -> typing_extensions___Literal["end_date_time", "end_time_type"]: ...
        @typing___overload
        def WhichOneof(
            self,
            oneof_group: typing_extensions___Literal[
                "spending_limit", b"spending_limit"
            ],
        ) -> typing_extensions___Literal[
            "spending_limit_micros", "spending_limit_type"
        ]: ...
    type___PendingAccountBudgetProposal = PendingAccountBudgetProposal

    resource_name: typing___Text = ...
    id: builtin___int = ...
    billing_setup: typing___Text = ...
    status: google___ads___googleads___v5___enums___account_budget_status_pb2___AccountBudgetStatusEnum.AccountBudgetStatusValue = ...
    name: typing___Text = ...
    proposed_start_date_time: typing___Text = ...
    approved_start_date_time: typing___Text = ...
    total_adjustments_micros: builtin___int = ...
    amount_served_micros: builtin___int = ...
    purchase_order_number: typing___Text = ...
    notes: typing___Text = ...
    proposed_end_date_time: typing___Text = ...
    proposed_end_time_type: google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue = ...
    approved_end_date_time: typing___Text = ...
    approved_end_time_type: google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue = ...
    proposed_spending_limit_micros: builtin___int = ...
    proposed_spending_limit_type: google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue = ...
    approved_spending_limit_micros: builtin___int = ...
    approved_spending_limit_type: google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue = ...
    adjusted_spending_limit_micros: builtin___int = ...
    adjusted_spending_limit_type: google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue = ...
    @property
    def pending_proposal(self) -> type___AccountBudget.PendingAccountBudgetProposal: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        billing_setup: typing___Optional[typing___Text] = None,
        status: typing___Optional[
            google___ads___googleads___v5___enums___account_budget_status_pb2___AccountBudgetStatusEnum.AccountBudgetStatusValue
        ] = None,
        name: typing___Optional[typing___Text] = None,
        proposed_start_date_time: typing___Optional[typing___Text] = None,
        approved_start_date_time: typing___Optional[typing___Text] = None,
        total_adjustments_micros: typing___Optional[builtin___int] = None,
        amount_served_micros: typing___Optional[builtin___int] = None,
        purchase_order_number: typing___Optional[typing___Text] = None,
        notes: typing___Optional[typing___Text] = None,
        pending_proposal: typing___Optional[
            type___AccountBudget.PendingAccountBudgetProposal
        ] = None,
        proposed_end_date_time: typing___Optional[typing___Text] = None,
        proposed_end_time_type: typing___Optional[
            google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue
        ] = None,
        approved_end_date_time: typing___Optional[typing___Text] = None,
        approved_end_time_type: typing___Optional[
            google___ads___googleads___v5___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue
        ] = None,
        proposed_spending_limit_micros: typing___Optional[builtin___int] = None,
        proposed_spending_limit_type: typing___Optional[
            google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue
        ] = None,
        approved_spending_limit_micros: typing___Optional[builtin___int] = None,
        approved_spending_limit_type: typing___Optional[
            google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue
        ] = None,
        adjusted_spending_limit_micros: typing___Optional[builtin___int] = None,
        adjusted_spending_limit_type: typing___Optional[
            google___ads___googleads___v5___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_approved_start_date_time",
            b"_approved_start_date_time",
            "_billing_setup",
            b"_billing_setup",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_notes",
            b"_notes",
            "_proposed_start_date_time",
            b"_proposed_start_date_time",
            "_purchase_order_number",
            b"_purchase_order_number",
            "adjusted_spending_limit",
            b"adjusted_spending_limit",
            "adjusted_spending_limit_micros",
            b"adjusted_spending_limit_micros",
            "adjusted_spending_limit_type",
            b"adjusted_spending_limit_type",
            "approved_end_date_time",
            b"approved_end_date_time",
            "approved_end_time",
            b"approved_end_time",
            "approved_end_time_type",
            b"approved_end_time_type",
            "approved_spending_limit",
            b"approved_spending_limit",
            "approved_spending_limit_micros",
            b"approved_spending_limit_micros",
            "approved_spending_limit_type",
            b"approved_spending_limit_type",
            "approved_start_date_time",
            b"approved_start_date_time",
            "billing_setup",
            b"billing_setup",
            "id",
            b"id",
            "name",
            b"name",
            "notes",
            b"notes",
            "pending_proposal",
            b"pending_proposal",
            "proposed_end_date_time",
            b"proposed_end_date_time",
            "proposed_end_time",
            b"proposed_end_time",
            "proposed_end_time_type",
            b"proposed_end_time_type",
            "proposed_spending_limit",
            b"proposed_spending_limit",
            "proposed_spending_limit_micros",
            b"proposed_spending_limit_micros",
            "proposed_spending_limit_type",
            b"proposed_spending_limit_type",
            "proposed_start_date_time",
            b"proposed_start_date_time",
            "purchase_order_number",
            b"purchase_order_number",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_approved_start_date_time",
            b"_approved_start_date_time",
            "_billing_setup",
            b"_billing_setup",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_notes",
            b"_notes",
            "_proposed_start_date_time",
            b"_proposed_start_date_time",
            "_purchase_order_number",
            b"_purchase_order_number",
            "adjusted_spending_limit",
            b"adjusted_spending_limit",
            "adjusted_spending_limit_micros",
            b"adjusted_spending_limit_micros",
            "adjusted_spending_limit_type",
            b"adjusted_spending_limit_type",
            "amount_served_micros",
            b"amount_served_micros",
            "approved_end_date_time",
            b"approved_end_date_time",
            "approved_end_time",
            b"approved_end_time",
            "approved_end_time_type",
            b"approved_end_time_type",
            "approved_spending_limit",
            b"approved_spending_limit",
            "approved_spending_limit_micros",
            b"approved_spending_limit_micros",
            "approved_spending_limit_type",
            b"approved_spending_limit_type",
            "approved_start_date_time",
            b"approved_start_date_time",
            "billing_setup",
            b"billing_setup",
            "id",
            b"id",
            "name",
            b"name",
            "notes",
            b"notes",
            "pending_proposal",
            b"pending_proposal",
            "proposed_end_date_time",
            b"proposed_end_date_time",
            "proposed_end_time",
            b"proposed_end_time",
            "proposed_end_time_type",
            b"proposed_end_time_type",
            "proposed_spending_limit",
            b"proposed_spending_limit",
            "proposed_spending_limit_micros",
            b"proposed_spending_limit_micros",
            "proposed_spending_limit_type",
            b"proposed_spending_limit_type",
            "proposed_start_date_time",
            b"proposed_start_date_time",
            "purchase_order_number",
            b"purchase_order_number",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "total_adjustments_micros",
            b"total_adjustments_micros",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_approved_start_date_time", b"_approved_start_date_time"
        ],
    ) -> typing_extensions___Literal["approved_start_date_time"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_billing_setup", b"_billing_setup"],
    ) -> typing_extensions___Literal["billing_setup"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_notes", b"_notes"]
    ) -> typing_extensions___Literal["notes"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_proposed_start_date_time", b"_proposed_start_date_time"
        ],
    ) -> typing_extensions___Literal["proposed_start_date_time"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_purchase_order_number", b"_purchase_order_number"
        ],
    ) -> typing_extensions___Literal["purchase_order_number"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "adjusted_spending_limit", b"adjusted_spending_limit"
        ],
    ) -> typing_extensions___Literal[
        "adjusted_spending_limit_micros", "adjusted_spending_limit_type"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "approved_end_time", b"approved_end_time"
        ],
    ) -> typing_extensions___Literal[
        "approved_end_date_time", "approved_end_time_type"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "approved_spending_limit", b"approved_spending_limit"
        ],
    ) -> typing_extensions___Literal[
        "approved_spending_limit_micros", "approved_spending_limit_type"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "proposed_end_time", b"proposed_end_time"
        ],
    ) -> typing_extensions___Literal[
        "proposed_end_date_time", "proposed_end_time_type"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "proposed_spending_limit", b"proposed_spending_limit"
        ],
    ) -> typing_extensions___Literal[
        "proposed_spending_limit_micros", "proposed_spending_limit_type"
    ]: ...

type___AccountBudget = AccountBudget



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroupAdErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdGroupAdErrorValue = typing___NewType("AdGroupAdErrorValue", builtin___int)
    type___AdGroupAdErrorValue = AdGroupAdErrorValue
    AdGroupAdError: _AdGroupAdError
    class _AdGroupAdError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdGroupAdErrorEnum.AdGroupAdErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 0)
        UNKNOWN = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 1)
        AD_GROUP_AD_LABEL_DOES_NOT_EXIST = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 2
        )
        AD_GROUP_AD_LABEL_ALREADY_EXISTS = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 3
        )
        AD_NOT_UNDER_ADGROUP = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 4)
        CANNOT_OPERATE_ON_REMOVED_ADGROUPAD = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 5
        )
        CANNOT_CREATE_DEPRECATED_ADS = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 6
        )
        CANNOT_CREATE_TEXT_ADS = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 7
        )
        EMPTY_FIELD = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 8)
        RESOURCE_REFERENCED_IN_MULTIPLE_OPS = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 9
        )
        AD_TYPE_CANNOT_BE_PAUSED = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 10
        )
        AD_TYPE_CANNOT_BE_REMOVED = typing___cast(
            AdGroupAdErrorEnum.AdGroupAdErrorValue, 11
        )
    UNSPECIFIED = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 0)
    UNKNOWN = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 1)
    AD_GROUP_AD_LABEL_DOES_NOT_EXIST = typing___cast(
        AdGroupAdErrorEnum.AdGroupAdErrorValue, 2
    )
    AD_GROUP_AD_LABEL_ALREADY_EXISTS = typing___cast(
        AdGroupAdErrorEnum.AdGroupAdErrorValue, 3
    )
    AD_NOT_UNDER_ADGROUP = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 4)
    CANNOT_OPERATE_ON_REMOVED_ADGROUPAD = typing___cast(
        AdGroupAdErrorEnum.AdGroupAdErrorValue, 5
    )
    CANNOT_CREATE_DEPRECATED_ADS = typing___cast(
        AdGroupAdErrorEnum.AdGroupAdErrorValue, 6
    )
    CANNOT_CREATE_TEXT_ADS = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 7)
    EMPTY_FIELD = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 8)
    RESOURCE_REFERENCED_IN_MULTIPLE_OPS = typing___cast(
        AdGroupAdErrorEnum.AdGroupAdErrorValue, 9
    )
    AD_TYPE_CANNOT_BE_PAUSED = typing___cast(AdGroupAdErrorEnum.AdGroupAdErrorValue, 10)
    AD_TYPE_CANNOT_BE_REMOVED = typing___cast(
        AdGroupAdErrorEnum.AdGroupAdErrorValue, 11
    )
    type___AdGroupAdError = AdGroupAdError
    def __init__(self,) -> None: ...

type___AdGroupAdErrorEnum = AdGroupAdErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class HotelPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    HotelPlaceholderFieldValue = typing___NewType(
        "HotelPlaceholderFieldValue", builtin___int
    )
    type___HotelPlaceholderFieldValue = HotelPlaceholderFieldValue
    HotelPlaceholderField: _HotelPlaceholderField
    class _HotelPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 1)
        PROPERTY_ID = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 2
        )
        PROPERTY_NAME = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 3
        )
        DESTINATION_NAME = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 4
        )
        DESCRIPTION = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 5
        )
        ADDRESS = typing___cast(HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 6)
        PRICE = typing___cast(HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 7)
        FORMATTED_PRICE = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 8
        )
        SALE_PRICE = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 9
        )
        FORMATTED_SALE_PRICE = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 10
        )
        IMAGE_URL = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 11
        )
        CATEGORY = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 12
        )
        STAR_RATING = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 13
        )
        CONTEXTUAL_KEYWORDS = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 14
        )
        FINAL_URLS = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 15
        )
        FINAL_MOBILE_URLS = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 16
        )
        TRACKING_URL = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 17
        )
        ANDROID_APP_LINK = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 18
        )
        SIMILAR_PROPERTY_IDS = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 19
        )
        IOS_APP_LINK = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 20
        )
        IOS_APP_STORE_ID = typing___cast(
            HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 21
        )
    UNSPECIFIED = typing___cast(HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 0)
    UNKNOWN = typing___cast(HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 1)
    PROPERTY_ID = typing___cast(HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 2)
    PROPERTY_NAME = typing___cast(
        HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 3
    )
    DESTINATION_NAME = typing___cast(
        HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 4
    )
    DESCRIPTION = typing___cast(HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 5)
    ADDRESS = typing___cast(HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 6)
    PRICE = typing___cast(HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 7)
    FORMATTED_PRICE = typing___cast(
        HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 8
    )
    SALE_PRICE = typing___cast(HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 9)
    FORMATTED_SALE_PRICE = typing___cast(
        HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 10
    )
    IMAGE_URL = typing___cast(HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 11)
    CATEGORY = typing___cast(HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 12)
    STAR_RATING = typing___cast(
        HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 13
    )
    CONTEXTUAL_KEYWORDS = typing___cast(
        HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 14
    )
    FINAL_URLS = typing___cast(HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 15)
    FINAL_MOBILE_URLS = typing___cast(
        HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 16
    )
    TRACKING_URL = typing___cast(
        HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 17
    )
    ANDROID_APP_LINK = typing___cast(
        HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 18
    )
    SIMILAR_PROPERTY_IDS = typing___cast(
        HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 19
    )
    IOS_APP_LINK = typing___cast(
        HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 20
    )
    IOS_APP_STORE_ID = typing___cast(
        HotelPlaceholderFieldEnum.HotelPlaceholderFieldValue, 21
    )
    type___HotelPlaceholderField = HotelPlaceholderField
    def __init__(self,) -> None: ...

type___HotelPlaceholderFieldEnum = HotelPlaceholderFieldEnum



from typing import Any

class FeedItemServiceStub:
    GetFeedItem: Any = ...
    MutateFeedItems: Any = ...
    def __init__(self, channel: Any) -> None: ...

class FeedItemServiceServicer:
    def GetFeedItem(self, request: Any, context: Any) -> None: ...
    def MutateFeedItems(self, request: Any, context: Any) -> None: ...

def add_FeedItemServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
